aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.BL/Enumerations
diff options
context:
space:
mode:
authorRoy <Roy.mail.net@gmail.com>2023-05-09 14:26:43 +0300
committerRoy <Roy.mail.net@gmail.com>2023-05-09 14:26:43 +0300
commit34a674da227985f0dc5b24d2f79cbcfe49a31b04 (patch)
tree0ed2fdb2d6af601dfbe033ca04aff574d35ccea5 /Software/Visual_Studio/Tango.BL/Enumerations
parentf5ac681980059138858eabd2eeff6e0173f11e95 (diff)
downloadTango-34a674da227985f0dc5b24d2f79cbcfe49a31b04.tar.gz
Tango-34a674da227985f0dc5b24d2f79cbcfe49a31b04.zip
Updated events table.
Diffstat (limited to 'Software/Visual_Studio/Tango.BL/Enumerations')
-rw-r--r--Software/Visual_Studio/Tango.BL/Enumerations/EventTypeGroups.cs4
-rw-r--r--Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs144
2 files changed, 138 insertions, 10 deletions
diff --git a/Software/Visual_Studio/Tango.BL/Enumerations/EventTypeGroups.cs b/Software/Visual_Studio/Tango.BL/Enumerations/EventTypeGroups.cs
index 5ff1766d9..b8c9e677e 100644
--- a/Software/Visual_Studio/Tango.BL/Enumerations/EventTypeGroups.cs
+++ b/Software/Visual_Studio/Tango.BL/Enumerations/EventTypeGroups.cs
@@ -43,6 +43,8 @@ namespace Tango.BL.Enumerations
[Description("Transport")]
Transport = 11,
[Description("Jobs")]
- Jobs = 12
+ Jobs = 12,
+ [Description("Safety")]
+ Safety = 13
}
}
diff --git a/Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs b/Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs
index b7ee724e8..93732c9f3 100644
--- a/Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs
+++ b/Software/Visual_Studio/Tango.BL/Enumerations/EventTypes.cs
@@ -254,6 +254,24 @@ namespace Tango.BL.Enumerations
RFID_READER_MALFUNCTION_WASTE_SLOT_2 = 2024,
/// <summary>
+ /// (Communication failure. Cannot execute job)
+ /// </summary>
+ [Description("Communication failure. Cannot execute job")]
+ I2C3_COMMUNICATION_FAILURE = 2025,
+
+ /// <summary>
+ /// (Communication failure. Cannot execute job)
+ /// </summary>
+ [Description("Communication failure. Cannot execute job")]
+ I2C4_COMMUNICATION_FAILURE = 2026,
+
+ /// <summary>
+ /// (Communication failure. Cannot execute job)
+ /// </summary>
+ [Description("Communication failure. Cannot execute job")]
+ I2C_COMMUNICATION_FAILURE = 2027,
+
+ /// <summary>
/// (Thread break. Cannot execute job)
/// </summary>
[Description("Thread break. Cannot execute job")]
@@ -1322,6 +1340,42 @@ namespace Tango.BL.Enumerations
DYEING_HEAD_COVER_IS_OPEN = 5099,
/// <summary>
+ /// (Dyeing head voltage is too low. Cannot execute job)
+ /// </summary>
+ [Description("Dyeing head voltage is too low. Cannot execute job")]
+ DYEING_HEAD_VOLTAGE_1_TOO_LOW = 5100,
+
+ /// <summary>
+ /// (Dyeing head voltage is too low. Cannot execute job)
+ /// </summary>
+ [Description("Dyeing head voltage is too low. Cannot execute job")]
+ DYEING_HEAD_VOLTAGE_2_TOO_LOW = 5101,
+
+ /// <summary>
+ /// (Dyeing head voltage is too low. Cannot execute job)
+ /// </summary>
+ [Description("Dyeing head voltage is too low. Cannot execute job")]
+ DYEING_HEAD_VOLTAGE_3_TOO_LOW = 5102,
+
+ /// <summary>
+ /// (Dyeing head voltage break. Cannot execute job)
+ /// </summary>
+ [Description("Dyeing head voltage break. Cannot execute job")]
+ DYEING_HEAD_VOLTAGE_1_BREAK = 5103,
+
+ /// <summary>
+ /// (Dyeing head voltage break. Cannot execute job)
+ /// </summary>
+ [Description("Dyeing head voltage break. Cannot execute job")]
+ DYEING_HEAD_VOLTAGE_2_BREAK = 5104,
+
+ /// <summary>
+ /// (Dyeing head voltage break. Cannot execute job)
+ /// </summary>
+ [Description("Dyeing head voltage break. Cannot execute job")]
+ DYEING_HEAD_VOLTAGE_3_BREAK = 5105,
+
+ /// <summary>
/// (The temperature in the mixer is too high. Cannot execute job)
/// </summary>
[Description("The temperature in the mixer is too high. Cannot execute job")]
@@ -2174,6 +2228,66 @@ namespace Tango.BL.Enumerations
MID_TANK_10_FILL_TIMEOUT = 8039,
/// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_1_MALFUNCTION = 8040,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_2_MALFUNCTION = 8041,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_3_MALFUNCTION = 8042,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_4_MALFUNCTION = 8043,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_5_MALFUNCTION = 8044,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_6_MALFUNCTION = 8045,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_7_MALFUNCTION = 8046,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_8_MALFUNCTION = 8047,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_9_MALFUNCTION = 8048,
+
+ /// <summary>
+ /// (Malfunction in @ tank. Cannot fill @ ink)
+ /// </summary>
+ [Description("Malfunction in @ tank. Cannot fill @ ink")]
+ MID_TANK_10_MALFUNCTION = 8049,
+
+ /// <summary>
/// (Cannot detect air filter. Cannot execute job )
/// </summary>
[Description("Cannot detect air filter. Cannot execute job ")]
@@ -2330,16 +2444,16 @@ namespace Tango.BL.Enumerations
NO_WASTE_CARTRIDGE_AVAILABLE = 10002,
/// <summary>
- /// (Both waste cartridges are full. Cannot execute job. Please replace waste cartridges)
+ /// (Waste tank is full. Please perform waste emptying)
/// </summary>
- [Description("Both waste cartridges are full. Cannot execute job. Please replace waste cartridges")]
- ALL_WASTE_CARTRIDGES_FULL = 10003,
+ [Description("Waste tank is full. Please perform waste emptying")]
+ WASTE_TANK_FULL = 10003,
/// <summary>
/// (Cannot detect waste cartridge. Cannot execute job )
/// </summary>
- [Description("Cannot detect waste cartridge. Cannot execute job ")]
- WASTE_CARTRIDGE_PRESENCE_SENSOR_TIMEOUT = 10004,
+ [Description("Cartridges not inserted properly. Cannot execute job ")]
+ CARTRIDGES_NOT_INSERTED_PROPERLY = 10004,
/// <summary>
/// (Cannot identify waste cartridge. Cannot execute job )
@@ -3044,6 +3158,12 @@ namespace Tango.BL.Enumerations
E_TEMPERATURE_MEASUREMENT_ERROR = 108035,
/// <summary>
+ /// (Dryer internal temperature is too low. Cannot execute job)
+ /// </summary>
+ [Description("Dryer internal temperature is too low. Cannot execute job")]
+ E_DRYER_INTERNAL_TEMPERATURE_TOO_LOW = 108036,
+
+ /// <summary>
/// (Dyeing head zone current is out of range. Cannot execute job)
/// </summary>
[Description("Dyeing head zone current is out of range. Cannot execute job")]
@@ -3230,10 +3350,10 @@ namespace Tango.BL.Enumerations
E_DYEING_HEAD_CLEANER_MOTOR_MALFUNCTION = 110010,
/// <summary>
/// (Dryer blower has stopped. Cannot execute job.)
/// </summary>
- [Description("Dryer blower has stopped. Cannot execute job.")]
- E_DRYER_BLOWER_STOPPED = 111000,
+ [Description("No suction. Cannot execute job.")]
+ E_NO_SUCTION = 111000,
/// <summary>
/// (Dryer blower flow is too low. Cannot execute job)
@@ -3260,6 +3380,12 @@ namespace Tango.BL.Enumerations
E_AIR_FILTER_CLOGGED = 111004,
/// <summary>
+ /// (No circulation flow in blower. Cannot execute job)
+ /// </summary>
+ [Description("No circulation flow in blower. Cannot execute job")]
+ E_NO_CIRCULATION_FLOW_IN_DRYER = 111005,
+
+ /// <summary>
/// (Pressure in @ ink line too high. Cannot execute job)
/// </summary>
[Description("Pressure in @ ink line too high. Cannot execute job")]
@@ -2330,16 +2444,16 @@ namespace Tango.BL.Enumerations
/// <summary>
- /// (Cannot detect waste cartridge. Cannot execute job )
+ /// (Cartridges not inserted properly. Cannot execute job )
/// </summary>
@@ -3230,10 +3350,10 @@ namespace Tango.BL.Enumerations
E_DYEING_HEAD_CLEANER_MOTOR_MALFUNCTION = 110010,
/// <summary>
- /// (Dryer blower has stopped. Cannot execute job.)
+ /// (No suction. Cannot execute job.)
/// </summary>